aboutsummaryrefslogtreecommitdiffhomepage
path: root/autogen.sh
diff options
context:
space:
mode:
authorGravatar Feng Xiao <xfxyjwf@gmail.com>2015-06-15 18:21:48 -0700
committerGravatar Feng Xiao <xfxyjwf@gmail.com>2015-06-15 18:24:01 -0700
commite96ff30120a3834f7d1e31e43e591bf7cfbd731f (patch)
tree7e4c317912ac3809fbff11bb692084debd4a27eb /autogen.sh
parent4cbb612299eaf8259db25f5dcda46022fbd1db54 (diff)
Down-integrate from internal code base.
[ci skip] Change-Id: I9391c09640e0b0b2b21c45a97a1fc91814d95c5d
Diffstat (limited to 'autogen.sh')
-rwxr-xr-xautogen.sh23
1 files changed, 7 insertions, 16 deletions
diff --git a/autogen.sh b/autogen.sh
index 08966c63..8160313e 100755
--- a/autogen.sh
+++ b/autogen.sh
@@ -15,27 +15,18 @@ __EOF__
exit 1
fi
# Check that gtest is present. Usually it is already there since the
# directory is set up as an SVN external.
-if test ! -e gtest; then
- echo "Google Test not present. Fetching gtest-1.7.0 from the web..."
- curl -O https://googletest.googlecode.com/files/gtest-1.7.0.zip
- unzip -q gtest-1.7.0.zip
- rm gtest-1.7.0.zip
- mv gtest-1.7.0 gtest
+if test ! -e gmock; then
+ echo "Google Mock not present. Fetching gmock-1.7.0 from the web..."
+ curl -O https://googlemock.googlecode.com/files/gmock-1.7.0.zip
+ unzip -q gmock-1.7.0.zip
+ rm gmock-1.7.0.zip
+ mv gmock-1.7.0 gmock
fi
set -ex
-# Temporary hack: Must change C runtime library to "multi-threaded DLL",
-# otherwise it will be set to "multi-threaded static" when MSVC upgrades
-# the project file to MSVC 2005/2008. vladl of Google Test says gtest will
-# probably change their default to match, then this will be unnecessary.
-# One of these mappings converts the debug configuration and the other
-# converts the release configuration. I don't know which is which.
-sed -i -e 's/RuntimeLibrary="5"/RuntimeLibrary="3"/g;
- s/RuntimeLibrary="4"/RuntimeLibrary="2"/g;' gtest/msvc/*.vcproj
-
# TODO(kenton): Remove the ",no-obsolete" part and fix the resulting warnings.
autoreconf -f -i -Wall,no-obsolete
@@ -15,27 +15,18 @@ __EOF__
exit 1
fi
-# Check that gtest is present. Usually it is already there since the
+# Check that gmock is present. Usually it is already there since the
# directory is set up as an SVN external.